package
Version:
v0.0.0-...-1726717
Opens a new window with list of versions in this module.
Published: Apr 12, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Dependencies for sms provider
type Provider interface {
SendSMS(sendTo, messageBody string) error
}
Provider interface to send sms
New returns a new sms provider
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.